"""
:authors: lexek
:license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2021 lexek
"""

from .ostrat import *

__author__ = 'lexek'
__version__ = '1.0'
__email__ = 'minelanpro@gmail.com'